@@ -40,7 +40,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.12.6"
+__version__ = "1.12.8"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ADXL34x.git"
 _ADXL345_DEFAULT_ADDRESS: int = const(0x53)  # Assumes ALT address pin low
 
@@ -389,9 +389,7 @@ class ADXL345:
             self._write_register_byte(_REG_INT_ENABLE, active_interrupts)
             self._enabled_interrupts["tap"] = 2
         else:
-            raise ValueError(
-                "tap must be 0 to disable, 1 for single tap, or 2 for double tap"
-            )
+            raise ValueError("tap_count must be 1 for single tap or 2 for double tap")
 
     def disable_tap_detection(self) -> None:
         """Disable tap detection"""
